/*============================================================================
  File:     GenerateActivity.sql

  Summary:  This script can be used to create a simple table into which
			data can be loaded.

  Date:     June 2007

  SQL Server Version: 9.00.3054.00 (SP2)
------------------------------------------------------------------------------
  Copyright (C) 2007 Kimberly L. Tripp, SQLskills.com
  All rights reserved.

  For more scripts and sample code, check out 
    http://www.SQLskills.com

  This script is intended only as a supplement to demos and lectures
  given by Kimberly L. Tripp.  
  
  THIS CODE AND INFORMATION ARE PROVIDED "AS IS" WITHOUT WARRANTY OF 
  ANY KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT LIMITED 
  TO THE IMPLIED WARRANTIES OF MERCHANTABILITY AND/OR FITNESS FOR A
  PARTICULAR PURPOSE.
============================================================================*/

-- ============================================================================
-- ============================================================================
-- SETUP - LoadData Table Setup
-- NOTE: This table is used on the Principal to test a variety of performance
-- issues and latency issues depending on the Database Mirroring configuraiton.
-------------------------------------------------------------------------------

USE AdventureWorks
go

CREATE TABLE LoadData
(
	LoadDataID	int	IDENTITY,
	LoadDataWhen	datetime	CONSTRAINT LoadDataWhenDefault
									DEFAULT getdate(),
	LoadDataWho		sysname		CONSTRAINT LoadDataWhoDefault
									DEFAULT user_name(),
	LoadDataFiller	nchar(200)	CONSTRAINT LoadDataFillerDefault
									DEFAULT 'Junk data to fill the row'
)
go
-- ============================================================================

-- ============================================================================
-- ============================================================================
-- Scenario - Infinite loop test with slower insert rate
-- NOTE: This scenario inserts continuously - but at a slightly slowed
-- rate (with a delay of 200 ms.). You can alter the delay if you want
-- to increase/decrease the rate of insert. Be CAREFUL - do not forget
-- that this is running and walk away... the database is set to autogrow
-- and your virtual machine is setup with dynamic disks. This scenario will
-- only end when you end it OR when you completely run out of disk space...
-------------------------------------------------------------------------------
-- BE SURE TO FULLY TEST YOUR PRODUCTION ENVIRONMENT TO UNDERSTAND THE
-- SPECIFIC IMPACT THAT DATABASE MIRRORING WILL HAVE ON PERFORMANCE.
-------------------------------------------------------------------------------
WHILE 1=1
BEGIN
	INSERT LoadData DEFAULT VALUES
	WAITFOR DELAY '00:00:00.200'
END
go
-- ============================================================================

-- ============================================================================
-- ============================================================================
-- Scenario - Timed to test Load Performance and Latency
-- NOTE: This scenario is somewhat unfair as it tried to insert at the 
-- fastest rate possible. In most production scenarios your rate of insert
-- would not be this high. This scenario will be the most negatively affected 
-- by synchronous forms of mirroring. Asynchronous should not be as impacted. 
-- However, remember that this virtual server environment also has an 
-- impact on overall performance. 
-------------------------------------------------------------------------------
-- BE SURE TO FULLY TEST YOUR PRODUCTION ENVIRONMENT TO UNDERSTAND THE
-- SPECIFIC IMPACT THAT DATABASE MIRRORING WILL HAVE ON PERFORMANCE.
-------------------------------------------------------------------------------
DECLARE @EndTime	datetime,
		@TestTime	smallint,
		@RowCount	int
SET @TestTime = 120 -- specifies how many seconds the test will run
SET @EndTime = dateadd(ss, @TestTime, getdate())
SELECT @RowCount = count(*) FROM LoadData
WHILE getdate() < @EndTime
	INSERT LoadData DEFAULT VALUES
SELECT count(*) - @RowCount AS TotalRowsInserted,
	   convert(decimal, (count(*) - @RowCount))/@TestTime AS RowsInsertedPerSecond
FROM LoadData
go
-- Keep track of some of your statistics here:
-- TotalRowsInserted	RowsInsertedPerSecond
-- 22867				127.038888
-- ============================================================================


